@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -23,9 +26,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-aurora-globaldatabase",
-    "1.1.439",
+    "1.1.615",
     __name__[0:-6],
-    "cdk-aurora-globaldatabase@1.1.439.jsii.tgz",
+    "cdk-aurora-globaldatabase@1.1.615.jsii.tgz",
 )
 
 __all__ = [
